pub struct DistillSuggestion {
pub field: String,
pub evidence_count: usize,
pub sample_evidence_drawer_ids: Vec<String>,
pub suggested_tier: String,
}Expand description
P106: a read-only suggestion that a field is worth distilling. The agent
MAY act on it via the explicit distill -> gate lifecycle; mempal never acts.
Fields
field: Stringevidence_count: usizesample_evidence_drawer_ids: Vec<String>suggested_tier: StringTrait Implementations
Sourceimpl Clone for DistillSuggestion
impl Clone for DistillSuggestion
Sourcefn clone(&self) -> DistillSuggestion
fn clone(&self) -> DistillSuggestion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DistillSuggestion
impl Debug for DistillSuggestion
impl Eq for DistillSuggestion
Sourceimpl PartialEq for DistillSuggestion
impl PartialEq for DistillSuggestion
Sourcefn eq(&self, other: &DistillSuggestion) -> bool
fn eq(&self, other: &DistillSuggestion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DistillSuggestion
impl Serialize for DistillSuggestion
impl StructuralPartialEq for DistillSuggestion