pub struct FactCheckReport {
pub issues: Vec<FactIssue>,
pub checked_entities: Vec<String>,
pub kg_triples_scanned: usize,
}Fields
issues: Vec<FactIssue>checked_entities: Vec<String>kg_triples_scanned: usizeTrait Implementations
Sourceimpl Clone for FactCheckReport
impl Clone for FactCheckReport
Sourcefn clone(&self) -> FactCheckReport
fn clone(&self) -> FactCheckReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FactCheckReport
impl Debug for FactCheckReport
Sourceimpl Default for FactCheckReport
impl Default for FactCheckReport
Sourcefn default() -> FactCheckReport
fn default() -> FactCheckReport
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FactCheckReport
impl<'de> Deserialize<'de> for FactCheckReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FactCheckReport
impl JsonSchema for FactCheckReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FactCheckReport
impl RefUnwindSafe for FactCheckReport
impl Send for FactCheckReport
impl Sync for FactCheckReport
impl Unpin for FactCheckReport
impl UnsafeUnpin for FactCheckReport
impl UnwindSafe for FactCheckReport