pub struct IngestOptions<'a> {
pub room: Option<&'a str>,
pub source_root: Option<&'a Path>,
pub dry_run: bool,
pub source_file_override: Option<&'a str>,
pub replace_existing_source: bool,
pub replace_across_rooms: bool,
pub no_strip_noise: bool,
pub diary_rollup: bool,
pub diary_rollup_day: Option<&'a str>,
pub project_filter: ProjectPathFilterOptions,
}Fields
room: Option<&'a str>source_root: Option<&'a Path>dry_run: boolsource_file_override: Option<&'a str>replace_existing_source: boolreplace_across_rooms: boolWhen replacing an existing source, delete its prior drawers across all
rooms (not just the freshly resolved room). Reindex sets this so a
source that re-routes to a new room does not leave stale drawers behind
in its old room. Ignored unless replace_existing_source is true.
no_strip_noise: booldiary_rollup: booldiary_rollup_day: Option<&'a str>project_filter: ProjectPathFilterOptionsTrait Implementations
Sourceimpl<'a> Clone for IngestOptions<'a>
impl<'a> Clone for IngestOptions<'a>
Sourcefn clone(&self) -> IngestOptions<'a>
fn clone(&self) -> IngestOptions<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for IngestOptions<'a>
impl<'a> Debug for IngestOptions<'a>
Sourceimpl<'a> Default for IngestOptions<'a>
impl<'a> Default for IngestOptions<'a>
Sourcefn default() -> IngestOptions<'a>
fn default() -> IngestOptions<'a>
Returns the “default value” for a type. Read more