pub struct ProjectSummary {
pub wing: String,
pub path: Option<String>,
pub last_activity: String,
pub total: i64,
pub evidence: i64,
pub knowledge: i64,
}Expand description
One project’s at-a-glance summary, derived from its drawers.
Fields
wing: Stringpath: Option<String>Absolute worktree path from the latest worktree:// anchor, or null when
the project only has legacy repo://legacy anchors.
last_activity: StringEpoch-seconds (string) of the most recent drawer in this wing.
total: i64evidence: i64knowledge: i64Trait Implementations
Sourceimpl Clone for ProjectSummary
impl Clone for ProjectSummary
Sourcefn clone(&self) -> ProjectSummary
fn clone(&self) -> ProjectSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectSummary
impl Debug for ProjectSummary
Sourceimpl JsonSchema for ProjectSummary
impl JsonSchema for ProjectSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectSummary
impl RefUnwindSafe for ProjectSummary
impl Send for ProjectSummary
impl Sync for ProjectSummary
impl Unpin for ProjectSummary
impl UnsafeUnpin for ProjectSummary
impl UnwindSafe for ProjectSummary