pub struct ResumeCandidate {
pub drawer_id: String,
pub statement: Option<String>,
pub tier: Option<String>,
}Expand description
An in-flight candidate knowledge drawer (distilled but not yet promoted).
Fields
drawer_id: Stringstatement: Option<String>tier: Option<String>Trait Implementations
Sourceimpl Clone for ResumeCandidate
impl Clone for ResumeCandidate
Sourcefn clone(&self) -> ResumeCandidate
fn clone(&self) -> ResumeCandidate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResumeCandidate
impl Debug for ResumeCandidate
Sourceimpl JsonSchema for ResumeCandidate
impl JsonSchema for ResumeCandidate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResumeCandidate
impl RefUnwindSafe for ResumeCandidate
impl Send for ResumeCandidate
impl Sync for ResumeCandidate
impl Unpin for ResumeCandidate
impl UnsafeUnpin for ResumeCandidate
impl UnwindSafe for ResumeCandidate