pub struct ResumeEvidence {
pub drawer_id: String,
pub source_file: Option<String>,
pub snippet: String,
pub added_at: String,
pub importance: i64,
}Expand description
A recent evidence drawer, for the resume pack.
Fields
drawer_id: Stringsource_file: Option<String>snippet: Stringadded_at: Stringimportance: i64Trait Implementations
Sourceimpl Clone for ResumeEvidence
impl Clone for ResumeEvidence
Sourcefn clone(&self) -> ResumeEvidence
fn clone(&self) -> ResumeEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResumeEvidence
impl Debug for ResumeEvidence
Sourceimpl JsonSchema for ResumeEvidence
impl JsonSchema for ResumeEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResumeEvidence
impl RefUnwindSafe for ResumeEvidence
impl Send for ResumeEvidence
impl Sync for ResumeEvidence
impl Unpin for ResumeEvidence
impl UnsafeUnpin for ResumeEvidence
impl UnwindSafe for ResumeEvidence